WHAT NEW IN X11.01 SUN

X 上的 AI 合集档案 · 22 个合集 · 64,204 条

jevPOST

Jev + Jevcache + Fable 实测:单次决策 220–780ms

作者对比 Jev 与 Claude 的循环决策开销,称决策成本降约 50 倍,缓存重跑让整体提速 26%。

Varun
@varun_mathur2026.09.21收录原推发布于 2026.09.21
Varun @varun_mathur原推发布于 2026.09.21
在 X 上打开原推

noticed below cumulative impact of using Jev + Jevcache + Fable: - Per-decision: ~220–780ms Jev vs 20–40s claude before - Loop's decisions are ~50× cheaper; Fable was consulted only on the 3 low-confidence steps - jevcache: earlier identical-phrasing re-run showed cached (0ms replay) live.. repeat run was 26% faster (7.2→5.3 min)

这条是引用着另一条写的:x.com/varun_mathur/status/2101371145521905688

x.com/varun_mathur/status/2101740594754093349采集于 2026.09.21 10:14